from setuptools import setup

setup(
    name="i-PI",
    version="2.4.1",
    install_requires=["ipi"],
    description="This package is deprecated. Please use 'ipi' instead.",
    long_description="This package is deprecated. Please use 'ipi' instead.",
    long_description_content_type="text/plain",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 7 - Inactive",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
    ],
    python_requires='>=3.6',
)
